==> fixYabinary-0.2.8-py3-none-any.whl: signature.py <==
#!/usr/bin/env python
# coding: UTF-8

headers = {# GRAPHICS FILES
           'jpg': ['ffd8ff'],
           'png': ['89504e470d0a1a0a0000000d49484452'],
           'gif': ['474946383761',
                   '474946383961'],
           'tif': ['49492a00'],
           # AOL ART files
           'art': ['4a47040e',
                   '4a47030e'],
           'pdf': ['25504446'],
           # Word documents
           'doc': ['d0cf11e0a1b1'],
           'pst': ['21424ea56fb5a6'],
           'ost': ['2142444e'],
           # Outlook Express
           'dbx': ['cfad12fec5fd746f'],
           'idx': ['4a4d4639'],
           'mbx': ['4a4d4636'],
           # AOL Mailbox
           'mail': ['414f4c564d'],
           # PGP (PRETTY GOOD PRIVACY)
           # PGP Disk Files
           'pgd': ['504750644d41494e6001'],
           # Public Key Ring
           'pgp': ['9900'],
           # Security Ring
           'pgp': ['9501',
                   '9500'],
           # Encrypted Data or ASCII armored keys
           'pgp': ['a600'],
           # RPM (Linux package format)
           'rpm': ['edab'],
           'zip': ['504b0304',
                   '504b0506',
                   '504b0708',
                   '504b4c495445',
                   '504b537058',
                   '57696e5a6970'],
           '7zip': ['377abcaf271c'],
           'rar': ['526172211a0700'],
           # SOUND FILES
           # Real Audio Files
           'ra': ['2e7261fd'],
           'asf': ['3026B2758E66CF11A6D900AA0062CE6C'],
           'wmv': ['3026B2758E66CF11A6D900AA0062CE6C'],
           'wma': ['3026B275',
                   '3026B275'],
           # MPEG Video
           'mpg': ['000001ba',
                   '000001b3'],
           'mp3': ['57415645',
                   'FFFBD0',
                   '494433',
                   '4C414D45'],
           'mp4': ['6674797033677035',
                   '667479704D534E56',
                   '6674797069736F6D'],
           # WINDOWS REGISTRY FILES
           'lnk': ['4C0000000114020000000000C00000'],
           'chm': ['495453460300000060000000010000'],
           'rdp': ['FFFE730063007200650065006E0020006D'],
           # ScanSoft PaperPort "Max" files
           'max': ['566947466b1a00000000'],
           # MISCELLANEOUS
           'exe': ['4d5a900003€000000'],
           'java': ['cafebabe'],
           # PINs Password Manager program
           'pins': ['50494e5320342e32300d']}

footers = {# GRAPHICS FILES
           'jpg': ['ffd9'],
           'png': ['0000000049454e44ae426082'],
           'gif': ['003b'],
           # AOL ART files
           'art': ['cfc7cb',
                   'd0cb0000'],
           'pdf': ['0a2525454f46',
                   '0a2525454f460a',
                   '0d0a2525454f460d0a',
                   '0d2525454f460d'],
           'zip': ['3cac'],
           # SOUND FILES
           # MPEG Video
           'mpg': ['000001b9',
                   '000001b7'],
           'wma': ['000000FF',
                   '529A1246'],
           'mp3': ['0000FF',
                   'D13551CC'],
           # ScanSoft PaperPort "Max" files
           'max': ['000005800000 ']}

==> fixYabinary-0.2.9-py3-none-any.whl: signature.py <==
#!/usr/bin/env python
# coding: UTF-8

headers = {# GRAPHICS FILES
           'jpg': ['ffd8ff'],
           'png': ['89504e470d0a1a0a0000000d49484452'],
           'gif': ['474946383761',
                   '474946383961'],
           'tif': ['49492a00'],
           # AOL ART files
           'art': ['4a47040e',
                   '4a47030e'],
           'pdf': ['25504446'],
           # Word documents
           'doc': ['d0cf11e0a1b1'],
           'pst': ['21424ea56fb5a6'],
           'ost': ['2142444e'],
           # Outlook express
           'dbx': ['cfad12fec5fd746f'],
           'idx': ['4a4d4639'],
           'mbx': ['4a4d4636'],
           # AOL Mailbox
           'mail': ['414f4c564d'],
           # PGP (PRETTY GOOD PRIVACY)
           # PGP disk files
           'pgd': ['504750644d41494e6001'],
           # Public Key Ring
           'pgp': ['9900'],
           # Security Ring
           'pgp': ['9501',
                   '9500'],
           # encrypted data or ASCII armored keys
           'pgp': ['a600'],
           # RPM (Linux package format)
           'rpm': ['edab'],
           'zip': ['504b0304',
                   '504b0506',
                   '504b0708',
                   '504b4c495445',
                   '504b537058',
                   '57696e5a6970'],
           '7zip': ['377abcaf271c'],
           'rar': ['526172211a0700'],
           # SOUND FILES
           # Real audio files
           'ra': ['2e7261fd'],
           'asf': ['3026b2758e66cf11a6d900aa0062ce6c'],
           'wmv': ['3026b2758e66cf11a6d900aa0062ce6c'],
           'wma': ['3026B275',
                   '3026B275'],
           # MPEG Video
           'mpg': ['000001ba',
                   '000001b3'],
           'mp3': ['57415645',
                   'fffbd0',
                   '494433',
                   '4c414d45'],
           'mp4': ['6674797033677035',
                   '667479704d534e56',
                   '6674797069736f6d'],
           # WINDOWS REGISTRY FILES
           'lnk': ['4c0000000114020000000000c00000'],
           'chm': ['495453460300000060000000010000'],
           'rdp': ['fffe730063007200650065006e0020006d'],
           # ScanSoft PaperPort "Max" files
           'max': ['566947466b1a00000000'],
           # MISCELLANEOUS
           'exe': ['4d5a'],
           'java': ['cafebabe'],
           'xml': ['3c3f786d6c'],
           'html': ['3c21646f63747970652068746d6c3e',
                    '3c21444f43545950452068746d6c3e'],
           # PINs Password Manager program
           'pins': ['50494e5320342e32300d']}

footers = {# GRAPHICS FILES
           'jpg': ['ffd9'],
           'png': ['0000000049454e44ae426082'],
           'gif': ['003b'],
           # AOL ART files
           'art': ['cfc7cb',
                   'd0cb0000'],
           'pdf': ['0a2525454f46',
                   '0a2525454f460a',
                   '0d0a2525454f460d0a',
                   '0d2525454f460d'],
           'zip': ['3cac'],
           # SOUND FILES
           # MPEG Video
           'mpg': ['000001b9',
                   '000001b7'],
           'wma': ['000000ff',
                   '529a1246'],
           'mp3': ['0000ff',
                   'd13551cc'],
           # ScanSoft PaperPort "Max" files
           'max': ['000005800000'],
           # MISCELLANEOUS
           'html': ['3c2f68746d6c3e']}
